# RawElementsRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**elements** | [**[RawElementRequest]**](RawElementRequest.md) |  | 
**units** | [**[RawUnitRequest], none_type**](RawUnitRequest.md) |  | [optional] 
**definitions** | [**[RawDefinitionRequest], none_type**](RawDefinitionRequest.md) |  | [optional] 
**property_sets** | [**[RawPropertySetRequest], none_type**](RawPropertySetRequest.md) |  | [optional] 
**classifications** | [**[RawClassificationRequest], none_type**](RawClassificationRequest.md) |  | [optional] 
**layers** | [**[RawLayerRequest], none_type**](RawLayerRequest.md) |  | [optional] 
**systems** | [**[RawSystemRequest], none_type**](RawSystemRequest.md) |  | [optional] 
**materials** | **bool, date, datetime, dict, float, int, list, str, none_type** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


